@@ -1,6 +1,6 @@
 # shellcheck shell=bash disable=SC2148
-# shellcheck source=./ftp-url.sh
-source "${OPENCOARRAYS_SRC_DIR}/prerequisites/build-functions/ftp-url.sh"
+# shellcheck source=./ftp_url.sh
+source "${OPENCOARRAYS_SRC_DIR}/prerequisites/build-functions/ftp_url.sh"
 # shellcheck source=./set_SUDO_if_needed_to_write_to_directory.sh
 source "${OPENCOARRAYS_SRC_DIR}/prerequisites/build-functions/set_SUDO_if_needed_to_write_to_directory.sh"
 
@@ -13,29 +13,61 @@ download_if_necessary()
 
   # We set args regardless of whether this function performs a download because
   # GCC builds will need this to modify GCC's contrib/download_prerequisites script
-  if [[ "${fetch}" == "svn" ]]; then
-    if [[ "${arg_B:-}" == "gcc" ]]; then
-      args=("ls")
-    else
-      args=("checkout")
-    fi
-  elif [[ "${fetch}" == "wget" ]]; then
-    args=("--no-check-certificate")
-  elif [[ "${fetch}" == "ftp-url" ]]; then
-    args=("-n")
-  elif [[ "${fetch}" == "git" ]]; then
-    args=("clone")
-  elif [[ "${fetch}" == "curl" ]]; then
-    first_three_characters=$(echo "${package_url}" | cut -c1-3)
-    if [[ "${first_three_characters}" == "ftp"  ]]; then
-      args=("-LO" "-u" "anonymous:")
-    elif [[ "${first_three_characters}" == "htt"  ]]; then
-      args=("-LO")
-    else
-      emergency "download_if_necessary.sh: Unrecognized URL."
-    fi
-  fi
 
+  case "${fetch}" in
+    "wget" )
+      args=("--no-check-certificate")
+      ;;
+    "ftp_url" )
+      args=("-n")
+      ;;
+    "git" )
+      args=("clone")
+      ;;
+    "svn" )
+       case "${arg_B:-}" in 
+         "gcc") 
+           args=("ls")
+           ;; 
+         *) 
+           args=("checkout")
+         ;;
+       esac
+       ;;
+    "curl" )
+      first_three_characters=$(echo "${package_url}" | cut -c1-3)
+      case "${first_three_characters}" in
+        "ftp"  )
+           args=("-LO" "-u" "anonymous: ")
+        ;; 
+        "htt"  )
+           args=("-LO")
+        ;; 
+        *)
+          emergency "download_if_necessary.sh: Unrecognized URL."
+        ;;
+      esac
+      ;;
+    *)
+      emergency "download_if_necessary.sh: Unrecognized \${fetch}=${fetch}."
+      ;; 
+  esac
+
+  case "${gcc_prereqs_fetch}" in
+    "wget" )
+      gcc_prereqs_fetch_args=("--no-check-certificate")
+      ;;
+    "ftp_url" )
+      gcc_prereqs_fetch_args=("-n")
+      ;;
+    "curl" )
+      gcc_prereqs_fetch_args=("-LO" "-u" "anonymous: ")
+      ;; 
+    *)
+      emergency "download_if_necessary.sh: Unrecognized \${gcc_prereqs_fetch}=${gcc_prereqs_fetch}."
+      ;;
+   esac
+  
   if  [[ -f "${download_path}/${url_tail}" || -d "${download_path}/${url_tail}" ]] ; then
     info "Found '${url_tail}' in ${download_path}."
     info "If it resulted from an incomplete download, building ${package_name} could fail."
