@@ -8,7 +8,7 @@ find_or_install()
   package_executable_array=(
     "gcc:gfortran"
     "cmake:cmake"
-    "mpich:mpif90"
+    "mpich:mpifort"
     "flex:flex"
     "bison:yacc"
     "m4:m4"
@@ -66,7 +66,17 @@ find_or_install()
     # Every branch that discovers an acceptable pre-existing installation must set the
     # CMAKE environment variable. Every branch must also manage the dependency stack.
 
-    if [[ "$script_installed_package" == true ]]; then
+    # If the user specified a CMake binary, use it
+    if [[ ! -z "${arg_m:-}" ]]; then
+
+      echo -e "$this_script: Using the $package specified by -m or --with-cmake: ${arg_m}\n"
+      export CMAKE="${arg_m}"
+      # Halt the recursion
+      stack_push dependency_pkg "none"
+      stack_push dependency_exe "none"
+      stack_push dependency_path "none"
+
+    elif [[ "$script_installed_package" == true ]]; then
       echo -e "$this_script: Using the $package installed by $this_script\n"
       export CMAKE=$package_install_path/bin/$executable
       stack_push dependency_pkg "none"
@@ -111,11 +121,11 @@ find_or_install()
     # MPIFC, MPICC, and MPICXX environment variables. Every branch must also manage the
     # dependency stack.
 
-    # If the user specified a Fortran compiler, verify that mpif90 wraps the specified compiler
+    # If the user specified a Fortran compiler, verify that mpifort wraps the specified compiler
     if [[ ! -z "${arg_M:-}" ]]; then
 
       echo -e "$this_script: Using the $package specified by -M or --with-mpi: ${arg_M}\n"
-      export MPIFC="${arg_M}"/bin/mpif90
+      export MPIFC="${arg_M}"/bin/mpifort
       export MPICC="${arg_M}"/bin/mpicc
       export MPICXX="${arg_M}"/bin/mpicxx
       # Halt the recursion
@@ -126,7 +136,7 @@ find_or_install()
     elif [[ "$script_installed_package" == true ]]; then
 
       echo -e "$this_script: Using the $package installed by $this_script\n"
-      export MPIFC=$package_install_path/bin/mpif90
+      export MPIFC=$package_install_path/bin/mpifort
       export MPICC=$package_install_path/bin/mpicc
       export MPICXX=$package_install_path/bin/mpicxx
       # Halt the recursion
@@ -137,8 +147,8 @@ find_or_install()
     elif [[ "$package_in_path" == "true" ]]; then
 
       echo -e "$this_script: Checking whether $executable in PATH wraps gfortran... "
-      mpif90_version_header=$(mpif90 --version | head -1)
-      first_three_characters=$(echo "$mpif90_version_header" | cut -c1-3)
+      mpifort_version_header=$(mpifort --version | head -1)
+      first_three_characters=$(echo "$mpifort_version_header" | cut -c1-3)
       if [[ "$first_three_characters" != "GNU" ]]; then
         printf "no.\n"
         # Trigger 'find_or_install gcc' and subsequent build of $package
@@ -152,7 +162,7 @@ find_or_install()
 
           info "-f (or --with-fortran) argument detected with value ${arg_f}"
           printf "yes.\n %s: Using the specified %s.\n" "$this_script" "$executable"
-          export MPIFC=mpif90
+          export MPIFC=mpifort
           export MPICC=mpicc
           export MPICXX=mpicxx
 
@@ -175,7 +185,7 @@ find_or_install()
           fi
           if [[ "$acceptable" == "${is_true:-}" ]]; then
             printf "yes.\n %s: Using the $executable found in the PATH.\n" "$this_script"
-            export MPIFC=mpif90
+            export MPIFC=mpifort
             export MPICC=mpicc
             export MPICXX=mpicxx
 
@@ -266,7 +276,7 @@ find_or_install()
       info "$this_script: Checking whether $executable in PATH is version $(./build.sh -V gcc) or later..."
       $executable -o acceptable_compiler acceptable_compiler.f90 || true;
       $executable -o print_true print_true.f90 || true;
-      if [[ -f ./accepatable_compiler && -f ./print_true ]]; then
+      if [[ -f ./acceptable_compiler && -f ./print_true ]]; then
         is_true=$(./print_true)
         acceptable=$(./acceptable_compiler)
         rm acceptable_compiler print_true
@@ -627,8 +637,8 @@ find_or_install()
             export LD_LIBRARY_PATH="$gfortran_lib_paths:$LD_LIBRARY_PATH"
           fi
         elif [[ $package == "mpich" ]]; then
-          echo "$this_script: export MPIFC=$package_install_path/bin/mpif90"
-                              export MPIFC="$package_install_path/bin/mpif90"
+          echo "$this_script: export MPIFC=$package_install_path/bin/mpifort"
+                              export MPIFC="$package_install_path/bin/mpifort"
           echo "$this_script: export MPICC= $package_install_path/bin/mpicc"
                               export MPICC="$package_install_path/bin/mpicc"
           echo "$this_script: export MPICXX=$package_install_path/bin/mpicxx"
